Learn R Programming

ARPALData (version 1.6.1)

get_ARPA_Lombardia_AQ_registry: Download metadata (registry) on air quality monitoring stations from ARPA Lombardia website

Description

'get_ARPA_Lombardia_AQ_registry' returns the registry (list) of all the air quality sensors and stations belonging to the ARPA Lombardia network. The information reported are: ID of each sensor and station, geo-location (coordinates in degrees), altitude (mt), starting date and ending date. The column 'NameStation' identifies the name of each station, while 'IDStation' is an ID code (assigned from ARPA) uniquely identifying each station. For more information about the municipal data visit the section 'Monitoraggio aria' at the webpage: https://www.dati.lombardia.it/stories/s/auv9-c2sj

Usage

get_ARPA_Lombardia_AQ_registry()

Arguments

Value

A data frame of class 'data.frame' and 'ARPALdf'. The object is fully compatible with Tidyverse.

Examples

Run this code
get_ARPA_Lombardia_AQ_registry()

Run the code above in your browser using DataLab