View source: R/get_ARPA_Lombardia_zoning.R
| get_ARPA_Lombardia_zoning | R Documentation |
'get_ARPA_Lombardia_zoning' returns the geometries (polygonal shape file) and a map of the ARPA zoning of Lombardy. The zoning reflects the main orographic characteristics of the territory. Lombardy region is classified into seven type of areas: large urbanized areas, urbanized areas in rural contexts, rural areas, mountainous areas and valley bottom. For more information, visit the section 'Zonizzazione ARPA Lombardia' at the websites https://www.arpalombardia.it/temi-ambientali/aria/rete-di-rilevamento/classificazione-zone/ and https://www.arpalombardia.it/temi-ambientali/aria/mappa-della-zonizzazione/
get_ARPA_Lombardia_zoning(
plot_map = TRUE,
title = "ARPA Lombardia zoning",
line_type = 1,
line_size = 1,
xlab = "Longitude",
ylab = "Latitude"
)
plot_map |
Logical value (FALSE or TRUE). If plot_map = TRUE, the ARPA Lombardia zoning is represented on a map, if plot_mat = FALSE only the geometry (polygon shapefile) is stored in the output. Default is plot_map = TRUE. |
title |
Title of the plot. Deafult is 'ARPA Lombardia zoning' |
line_type |
Linetype for the zones' borders. Default is 1. |
line_size |
Size of the line for the zones. Default is 1. |
xlab |
x-axis label. Default is 'Longitude'. |
ylab |
y-axis label. Default is 'Latitude'. |
The function returns an object of class 'sf' containing the polygon borders of the seven zones used by ARPA Lombardia to classify the regional territory. If plot_map = 1, it also returns a map of the zoning.
zones <- get_ARPA_Lombardia_zoning(plot_map = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.